@@ -46,7 +46,7 @@ AuthDialog::AuthDialog(const QString &actionId,
                        const PolkitQt1::Details &details,
                        const PolkitQt1::Identity::List &identities,
                        WId parent)
-    : QDialog(0)
+    : QDialog(nullptr)
 {
     // KAuth is able to circumvent polkit's limitations, and manages to send the wId to the auth agent.
     // If we received it, we use KWindowSystem to associate this dialog correctly.
@@ -113,7 +113,7 @@ AuthDialog::AuthDialog(const QString &actionId,
                                                            overlaySize,
                                                            KIconLoader::DefaultState,
                                                            QStringList(),
-                                                           0,
+                                                           nullptr,
                                                            true);
     // if we're able to load the action icon paint it over the
     // key icon.
@@ -323,7 +323,15 @@ AuthDetails::AuthDetails(const PolkitQt1::Details &details,
 {
     setupUi(this);
 
-    app_label->setText(appname);
+    // better N/A than a blank space
+    if (appname.isEmpty()) {
+        QFont nameFont = app_label->font();
+        nameFont.setItalic(true);
+        app_label->setFont(nameFont);
+        app_label->setText(i18n("Not Applicable"));
+    } else {
+        app_label->setText(appname);
+    }
 
     foreach(const QString &key, details.keys()) { //krazy:exclude=foreach (Details is not a map/hash, but rather a method)
         int row = gridLayout->rowCount() + 1;
@@ -333,12 +341,27 @@ AuthDetails::AuthDetails(const PolkitQt1::Details &details,
                                 "provided by polkit", "%1:", key));
         gridLayout->addWidget(keyLabel, row, 0);
 
+        keyLabel->setAlignment(Qt::AlignRight);
+        QFont lblFont(keyLabel->font());
+        lblFont.setBold(true);
+        keyLabel->setFont(lblFont);
+
         QLabel *valueLabel = new QLabel(this);
         valueLabel->setText(details.lookup(key));
         gridLayout->addWidget(valueLabel, row, 1);
     }
 
-    action_label->setText(actionDescription.description());
+    // replace blank description
+    // neither isEmpty() or isNull() worked (?)
+    if (actionDescription.description() == "") {
+        QFont descrFont(action_label->font());
+        descrFont.setItalic(true);
+        action_label->setFont(descrFont);
+        action_label->setText(i18n("Not Applicable"));
+    } else {
+        action_label->setText(actionDescription.description());
+    }
+
     action_id_label->setText(actionDescription.actionId());
 
     QString vendor    = actionDescription.vendorName();
